@@ -1,28 +1,21 @@
-from naas.types import t_notebook, t_health, t_error, t_start, t_delete
+from naas.ntypes import t_notebook, t_health, t_error, t_start, t_delete
 from sanic.views import HTTPMethodView
 from sanic.exceptions import ServerError
 import urllib
 import uuid
 
 
-def rename_keys(old_dict):
-    new_dict = {}
-    for key in old_dict.keys():
-        new_key = key.replace(" ", "_")
-        new_key = new_key.replace("-", "_")
-        new_dict[new_key] = old_dict[key]
-    return new_dict
-
-
 def parse_data(request):
     req_data = {}
-    if request.headers.get("content-type") == "multipart/form-data":
+    ctype = request.headers.get("content-type", "")
+    if ctype.startswith("multipart/form-data"):
         req_data = request.files
-    elif request.headers.get("content-type") == "application/json":
+    elif ctype.startswith("application/json"):
         req_data = request.json
-    elif request.headers.get("content-type") == "application/x-www-form-urlencoded":
+    elif ctype.startswith("application/x-www-form-urlencoded"):
         req_data = dict(urllib.parse.parse_qsl(request.body.decode("utf-8")))
-    req_data = rename_keys(req_data)
+    else:
+        req_data = str(request.body.decode("utf-8"))
     args = dict(
         urllib.parse.parse_qsl(request.query_string)
     )  # fix to don't have array for each args
